@@ -513,7 +513,7 @@ apr_status_t redwax_complete_file(redwax_tool_t *r, const char *arg,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, initialise,
-        (redwax_tool_t *r));
+        (redwax_tool_t *r))
 
 /**
  * Hook to process incoming certificates / intermediates / keys.
@@ -521,7 +521,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, initialise,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_pem_in,
-        (redwax_tool_t *r, const char *arg, const char *secret));
+        (redwax_tool_t *r, const char *arg, const char *secret))
 
 /**
  * Hook to process incoming trusted certificates.
@@ -529,7 +529,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_pem_in,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_trust_pem_in,
-        (redwax_tool_t *r, const char *arg, const char *secret));
+        (redwax_tool_t *r, const char *arg, const char *secret))
 
 /**
  * Hook to complete PKCS11 URL in.
@@ -537,7 +537,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_trust_pem_in,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_pkcs11_in,
-        (redwax_tool_t *r, const char *url, apr_hash_t *urls));
+        (redwax_tool_t *r, const char *url, apr_hash_t *urls))
 
 /**
  * Hook to write incoming PKCS11 URL.
@@ -545,7 +545,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_pkcs11_in,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_pkcs11_in,
-        (redwax_tool_t *r, const char *arg, apr_hash_t *secrets));
+        (redwax_tool_t *r, const char *arg, apr_hash_t *secrets))
 
 /**
  * Hook to complete the module for the incoming PKCS11 URL.
@@ -553,7 +553,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_pkcs11_in,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_pkcs11_module_in,
-        (redwax_tool_t *r, const char *mod, redwax_token_quoted_e quoted));
+        (redwax_tool_t *r, const char *mod, redwax_token_quoted_e quoted))
 
 /**
  * Hook to specify the module for the incoming PKCS11 URL.
@@ -561,7 +561,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_pkcs11_module_in,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_pkcs11_module_in,
-        (redwax_tool_t *r, const char *arg));
+        (redwax_tool_t *r, const char *arg))
 
 /**
  * Hook to complete keychain in.
@@ -569,7 +569,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_pkcs11_module_in,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_keychain_in,
-        (redwax_tool_t *r, const char *url, apr_hash_t *urls));
+        (redwax_tool_t *r, const char *url, apr_hash_t *urls))
 
 /**
  * Hook to write incoming keychain entries.
@@ -577,7 +577,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_keychain_in,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_keychain_in,
-        (redwax_tool_t *r, const char *arg));
+        (redwax_tool_t *r, const char *arg))
 
 /**
  * Hook to complete incoming certificates / intermediates / keys
@@ -587,7 +587,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_keychain_in,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_filter,
-        (redwax_tool_t *r, apr_hash_t *filters));
+        (redwax_tool_t *r, apr_hash_t *filters))
 
 /**
  * Hook to process incoming certificates / intermediates / keys
@@ -597,7 +597,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_filter,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_filter,
-        (redwax_tool_t *r, const char *arg));
+        (redwax_tool_t *r, const char *arg))
 
 /**
  * Hook to write outgoing NSS database.
@@ -606,7 +606,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_filter,
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_nss_out,
         (redwax_tool_t *r, const char *path, const char *token,
-                apr_hash_t *secrets));
+                apr_hash_t *secrets))
 
 /**
  * Hook to complete outgoing NSS token.
@@ -614,7 +614,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_nss_out,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_nss_token_out,
-        (redwax_tool_t *r, apr_hash_t *tokens));
+        (redwax_tool_t *r, apr_hash_t *tokens))
 
 /**
  * Hook to write outgoing certificates / intermediates / keys.
@@ -622,7 +622,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_nss_token_out,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_der_out,
-        (redwax_tool_t *r, const char *arg, const char *secret));
+        (redwax_tool_t *r, const char *arg, const char *secret))
 
 /**
  * Hook to write outgoing certificates / intermediates / keys.
@@ -630,7 +630,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_der_out,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_pem_out,
-        (redwax_tool_t *r, const char *arg, const char *secret));
+        (redwax_tool_t *r, const char *arg, const char *secret))
 
 /**
  * Hook to write outgoing pkcs12 file.
@@ -638,7 +638,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_pem_out,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_pkcs12_out,
-        (redwax_tool_t *r, const char *arg, const char *secret));
+        (redwax_tool_t *r, const char *arg, const char *secret))
 
 /**
  * Hook to complete PKCS11 URL out.
@@ -646,7 +646,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_pkcs12_out,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_pkcs11_out,
-        (redwax_tool_t *r, const char *url, apr_hash_t *urls));
+        (redwax_tool_t *r, const char *url, apr_hash_t *urls))
 
 /**
  * Hook to write outgoing PKCS11 URL.
@@ -654,7 +654,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_pkcs11_out,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_pkcs11_out,
-        (redwax_tool_t *r, const char *arg, apr_hash_t *secrets));
+        (redwax_tool_t *r, const char *arg, apr_hash_t *secrets))
 
 /**
  * Hook to complete the module for the PKCS11 URL.
@@ -662,7 +662,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_pkcs11_out,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_pkcs11_module_out,
-        (redwax_tool_t *r, const char *mod, redwax_token_quoted_e quoted));
+        (redwax_tool_t *r, const char *mod, redwax_token_quoted_e quoted))
 
 /**
  * Hook to specify the module for the outgoing PKCS11 URL.
@@ -670,7 +670,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_pkcs11_module_out,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_pkcs11_module_out,
-        (redwax_tool_t *r, const char *arg));
+        (redwax_tool_t *r, const char *arg))
 
 /**
  * Hook to write outgoing PKCS12 file.
@@ -678,7 +678,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_pkcs11_module_out,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_pkcs12_in,
-        (redwax_tool_t *r, const char *arg, const char *secret));
+        (redwax_tool_t *r, const char *arg, const char *secret))
 
 /**
  * Hook to handle the output of metadata.
@@ -686,7 +686,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_pkcs12_in,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_metadata_out,
-        (redwax_tool_t *r, const char *arg));
+        (redwax_tool_t *r, const char *arg))
 
 /**
  * Hook to handle the output of calendar data.
@@ -694,7 +694,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_metadata_out,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_calendar_out,
-        (redwax_tool_t *r, const char *arg));
+        (redwax_tool_t *r, const char *arg))
 
 /**
  * Hook to handle the output of calendar (reminder) data.
@@ -702,7 +702,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_calendar_out,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_reminder_out,
-        (redwax_tool_t *r, const char *arg));
+        (redwax_tool_t *r, const char *arg))
 
 /**
  * Hook to write SSH public keys.
@@ -710,7 +710,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_reminder_out,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_ssh_public_out,
-        (redwax_tool_t *r, const char *arg, const char *secret));
+        (redwax_tool_t *r, const char *arg, const char *secret))
 
 /**
  * Hook to complete the metadata format.
@@ -718,7 +718,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_ssh_public_out,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_format_out,
-        (redwax_tool_t *r, apr_hash_t *formats));
+        (redwax_tool_t *r, apr_hash_t *formats))
 
 /**
  * Hook to set the metadata format.
@@ -726,7 +726,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_format_out,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, set_format_out,
-        (redwax_tool_t *r, const char *arg));
+        (redwax_tool_t *r, const char *arg))
 
 /**
  * Hook to complete the output order.
@@ -734,7 +734,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, set_format_out,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_order_out,
-        (redwax_tool_t *r, apr_hash_t *orders));
+        (redwax_tool_t *r, apr_hash_t *orders))
 
 /**
  * Hook to set the output order.
@@ -742,7 +742,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_order_out,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, set_order_out,
-        (redwax_tool_t *r, const char *arg));
+        (redwax_tool_t *r, const char *arg))
 
 /**
  * Hook to set the calendar alarm.
@@ -750,7 +750,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, set_order_out,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, set_calendar_alarm,
-        (redwax_tool_t *r, const char *arg));
+        (redwax_tool_t *r, const char *arg))
 
 /**
  * Hook to handle the output of JWK sets.
@@ -758,7 +758,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, set_calendar_alarm,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_jwks_out,
-        (redwax_tool_t *r, const char *arg));
+        (redwax_tool_t *r, const char *arg))
 
 /**
  * Hook to complete verification parameters.
@@ -766,7 +766,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_jwks_out,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_verify_param,
-        (redwax_tool_t *r, apr_hash_t *params));
+        (redwax_tool_t *r, apr_hash_t *params))
 
 /**
  * Hook to set the verification parameters.
@@ -774,7 +774,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_verify_param,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, set_verify_param,
-        (redwax_tool_t *r, const char *arg));
+        (redwax_tool_t *r, const char *arg))
 
 /**
  * Hook to set the verification date.
@@ -782,7 +782,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, set_verify_param,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, set_verify_date,
-        (redwax_tool_t *r, const char *arg));
+        (redwax_tool_t *r, const char *arg))
 
 /**
  * Hook to complete the verification expiry.
@@ -790,7 +790,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, set_verify_date,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_verify_expiry,
-        (redwax_tool_t *r, apr_hash_t *purposes));
+        (redwax_tool_t *r, apr_hash_t *purposes))
 
 /**
  * Hook to set the verification expiry.
@@ -798,7 +798,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_verify_expiry,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, set_verify_expiry,
-        (redwax_tool_t *r, const char *arg));
+        (redwax_tool_t *r, const char *arg))
 
 /**
  * Hook to complete verification dane.
@@ -806,7 +806,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, set_verify_expiry,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_verify_dane,
-        (redwax_tool_t *r, apr_hash_t *purposes));
+        (redwax_tool_t *r, apr_hash_t *purposes))
 
 /**
  * Hook to set the verification dane policy.
@@ -814,7 +814,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_verify_dane,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, set_verify_dane,
-        (redwax_tool_t *r, const char *arg));
+        (redwax_tool_t *r, const char *arg))
 
 /**
  * Hook to complete purposes.
@@ -822,7 +822,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, set_verify_dane,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_purpose,
-        (redwax_tool_t *r, apr_hash_t *purposes));
+        (redwax_tool_t *r, apr_hash_t *purposes))
 
 /**
  * Hook to set the purposes.
@@ -830,7 +830,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, complete_purpose,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, set_purpose,
-        (redwax_tool_t *r, const char *arg));
+        (redwax_tool_t *r, const char *arg))
 
 /**
  * Hook to set the tlsa.
@@ -838,7 +838,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, set_purpose,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, set_tlsa,
-        (redwax_tool_t *r, const char *arg));
+        (redwax_tool_t *r, const char *arg))
 
 /**
  * Hook to set the smimea.
@@ -846,7 +846,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, set_tlsa,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, set_smimea,
-        (redwax_tool_t *r, const char *arg));
+        (redwax_tool_t *r, const char *arg))
 
 /**
  * Hook to set the DNS server address.
@@ -854,7 +854,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, set_smimea,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, set_dns_server,
-        (redwax_tool_t *r, const char *arg));
+        (redwax_tool_t *r, const char *arg))
 
 /**
  * Hook to set the DNS trust anchor.
@@ -862,7 +862,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, set_dns_server,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, set_dns_trust_anchor,
-        (redwax_tool_t *r, const char *arg));
+        (redwax_tool_t *r, const char *arg))
 
 /**
  * Hook to search for intermediate and root certificates.
@@ -871,7 +871,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, set_dns_trust_anchor,
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, search_chain,
         (redwax_tool_t *r, const redwax_certificate_t *cert,
-                const redwax_certificate_t **current));
+                const redwax_certificate_t **current))
 
 /**
  * Hook to search for the key corresponding to a certificate.
@@ -879,7 +879,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, search_chain,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, search_key,
-        (redwax_tool_t *r, const redwax_certificate_t *cert));
+        (redwax_tool_t *r, const redwax_certificate_t *cert))
 
 /**
  * Hook to compare two certificates.
@@ -898,7 +898,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, search_key,
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, int, compare_certificate,
         (redwax_tool_t *r, const redwax_certificate_t *c1,
-                const redwax_certificate_t *c2));
+                const redwax_certificate_t *c2))
 
 /**
  * Hook to normalise a key.
@@ -906,7 +906,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, int, compare_certificate,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, normalise_key,
-        (redwax_tool_t *r, redwax_key_t *key, int index));
+        (redwax_tool_t *r, redwax_key_t *key, int index))
 
 /**
  * Hook to normalise a certificate.
@@ -914,7 +914,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, normalise_key,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, normalise_certificate,
-        (redwax_tool_t *r, redwax_certificate_t *cert, int index));
+        (redwax_tool_t *r, redwax_certificate_t *cert, int index))
 
 /**
  * Hook to add DNS entries to metadata.
@@ -924,7 +924,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, normalise_certificate,
  * @param cert The certificate.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, add_dns_metadata,
-        (redwax_tool_t *r, redwax_metadata_t *m, const redwax_certificate_t *cert));
+        (redwax_tool_t *r, redwax_metadata_t *m, const redwax_certificate_t *cert))
 
 /**
  * Hook to process DNS results.
@@ -934,7 +934,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, add_dns_metadata,
  * @param rdata The dns record.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_dns,
-        (redwax_tool_t *r, redwax_dns_t *dns, redwax_rdata_t *rdata));
+        (redwax_tool_t *r, redwax_dns_t *dns, redwax_rdata_t *rdata))
 
 /**
  * Hook to process TLSA results.
@@ -943,7 +943,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_dns,
  * @param dns The dns result.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_tlsa,
-        (redwax_tool_t *r, redwax_dns_t *dns));
+        (redwax_tool_t *r, redwax_dns_t *dns))
 
 /**
  * Hook to process SMIMEA results.
@@ -952,7 +952,7 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_tlsa,
  * @param dns The dns result.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_smimea,
-        (redwax_tool_t *r, redwax_dns_t *dns));
+        (redwax_tool_t *r, redwax_dns_t *dns))
 
 /**
  * Hook to run the pre-filter poll.
@@ -962,6 +962,6 @@ APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, process_smimea,
  * @param r The redwax-tool context.
  */
 APR_DECLARE_EXTERNAL_HOOK(rt, REDWAX, apr_status_t, filter_poll,
-        (redwax_tool_t *r));
+        (redwax_tool_t *r))
 
 #endif
