@@ -25,6 +25,6 @@
 
 #include "config.h"
 
-void redwax_add_default_ldns_hooks();
+void redwax_add_default_ldns_hooks(apr_pool_t *pool);
 
 #endif /* REDWAX_LDNS_H_ */
