@@ -27,7 +27,7 @@
 
 #if HAVE_LIBICAL_ICAL_H
 
-void redwax_add_default_libical_hooks();
+void redwax_add_default_libical_hooks(apr_pool_t *pool);
 
 #endif
 #endif /* REDWAX_LIBICAL_H_ */
