@@ -784,7 +784,7 @@ static apr_status_t redwax_nss_process_nss_out(redwax_tool_t *r,
     return APR_SUCCESS;
 }
 
-void redwax_add_default_nss_hooks()
+void redwax_add_default_nss_hooks(apr_pool_t *pool)
 {
     rt_hook_initialise(redwax_nss_initialise, NULL, NULL, APR_HOOK_MIDDLE);
     rt_hook_process_nss_out(redwax_nss_process_nss_out, NULL, NULL, APR_HOOK_MIDDLE);
@@ -793,7 +793,7 @@ void redwax_add_default_nss_hooks()
 
 #else
 
-void redwax_add_default_nss_hooks()
+void redwax_add_default_nss_hooks(apr_pool_t *pool)
 {
 }
 
